# PersonV30

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**last_modified_date** | [**LastModifiedDateV30**](LastModifiedDateV30.md) |  | [optional] 
**name** | [**NameV30**](NameV30.md) |  | [optional] 
**other_names** | [**OtherNamesV30**](OtherNamesV30.md) |  | [optional] 
**biography** | [**BiographyV30**](BiographyV30.md) |  | [optional] 
**researcher_urls** | [**ResearcherUrlsV30**](ResearcherUrlsV30.md) |  | [optional] 
**emails** | [**EmailsV30**](EmailsV30.md) |  | [optional] 
**addresses** | [**AddressesV30**](AddressesV30.md) |  | [optional] 
**keywords** | [**KeywordsV30**](KeywordsV30.md) |  | [optional] 
**external_identifiers** | [**PersonExternalIdentifiersV30**](PersonExternalIdentifiersV30.md) |  | [optional] 
**path** | **str** |  | [optional] 

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)

